#!/usr/bin/env python3
# -*- encoding: utf-8; py-indent-offset: 4 -*-
# (c) Louis Wevers <rudder-checkmk@wevers.tv> 2021

# This is free software;  you can redistribute it and/or modify it
# under the  terms of the  GNU General Public License  as published by
# the Free Software Foundation in version 2.  check_mk is  distributed
# in the hope that it will be useful, but WITHOUT ANY WARRANTY;  with-
# out even the implied warranty of  MERCHANTABILITY  or  FITNESS FOR A
# PARTICULAR PURPOSE. See the  GNU General Public License for more de-
# ails.  You should have  received  a copy of the  GNU  General Public
# License along with GNU Make; see the file  COPYING.  If  not,  write
# to the Free Software Foundation, Inc., 51 Franklin St,  Fifth Floor,
# Boston, MA 02110-1301 USA.


# Example for output from agent
# ---------------------------------------------------------
#<<<rudder_agent>>>
#(171s) 40 0 16 0 0 0 0 0

from .agent_based_api.v1 import *

def discover_rudder_agent(section):
    yield Service()

def check_rudder_agent(params, section):
    lastrun_warn = params["agent_lastrun"][0]
    lastrun_crit = params["agent_lastrun"][1]
    for lastrun, compliantcount, repaircount, nacount, errorcount, acompliantcount, anccout, anacount, aerr in section:
        lastrun = lastrun.replace("(","").replace(")","").replace("s","")
        lastrun         = int(lastrun)
        compliantcount  = int(compliantcount)
        repaircount     = int(repaircount)
        nacount         = int(nacount)
        errorcount      = int(errorcount)
        acompliantcount = int(acompliantcount)
        anccout         = int(anccout)
        anacount        = int(anacount)
        aerr            = int(aerr)

        disp_lastrun       = render.timespan(lastrun)
        disp_lastrun_warn  = render.timespan(lastrun_warn)
        disp_lastrun_crit  = render.timespan(lastrun_crit)

        yield Metric(
                name ="agent_lastrun", 
                value = lastrun,
                levels = (lastrun_warn,lastrun_crit)
                )
        yield Metric("Complientcount", compliantcount)
        yield Metric("Repaircount", repaircount)
        yield Metric("nacount", nacount)
        yield Metric("errorcount", errorcount)
        yield Metric("acomplientcount", acompliantcount)
        yield Metric("anccout", anccout)
        yield Metric("anacount", anacount)
        yield Metric("aerrorcount", aerr)
        if lastrun >= lastrun_crit or errorcount > 0 or aerr > 0:
            s=State.CRIT
            status="Crit"
        elif lastrun >= lastrun_warn:
            s=State.WARN
            status="Warn"
        else:
            s=State.OK
            status="OK"
        yield Result(
                state=s,
                summary = f"Rudder agent - {status}: Last run was {disp_lastrun} ago (Warn/Crit at {disp_lastrun_warn}/{disp_lastrun_crit}). There were {errorcount} errors in Enforce mode and {aerr} errors in Audit mode."
                )
        return

register.check_plugin(
    name = "rudder_agent",
    service_name = "Rudder agent",
    discovery_function = discover_rudder_agent,
    check_function = check_rudder_agent,
    check_default_parameters={'agent_lastrun' : (450,600)},
    check_ruleset_name="rudder_agent",)

